@@ -145,7 +145,8 @@ printfeed(FILE *fpitems, FILE *fpin, struct feed *f)
 			break;
 
 		parsedtime = 0;
-		strtotime(fields[FieldUnixTimestamp], &parsedtime);
+		if (strtotime(fields[FieldUnixTimestamp], &parsedtime))
+			continue;
 		if (!(tm = localtime(&parsedtime)))
 			err(1, "localtime");
 
@@ -216,9 +217,9 @@ printfeed(FILE *fpitems, FILE *fpin, struct feed *f)
 		f->totalnew += isnew;
 		f->total++;
 
-                fprintf(fpitems, "%04d-%02d-%02d&nbsp;%02d:%02d ",
-                       tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
-                       tm->tm_hour, tm->tm_min);
+		fprintf(fpitems, "%04d-%02d-%02d&nbsp;%02d:%02d ",
+		        tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
+		        tm->tm_hour, tm->tm_min);
 
 		if (isnew)
 			fputs("<b><u>", fpitems);
